@@ -35,7 +35,8 @@ import (
 	"strings"
 	"unicode/utf8"
 
-	fontCLI "github.com/jandedobbeleer/oh-my-posh/src/font"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
+	font_ "github.com/jandedobbeleer/oh-my-posh/src/font"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
@@ -109,42 +110,32 @@ func NewRGBColor(ansiColor string) *RGB {
 }
 
 type Renderer struct {
-	AnsiString    string
-	Author        string
-	CursorPadding int
-	RPromptOffset int
-	BgColor       string
-
-	env runtime.Environment
-
-	Path string
-
-	factor float64
-
-	columns int
-	rows    int
-
+	italic                 font.Face
+	env                    runtime.Environment
+	bold                   font.Face
+	regular                font.Face
 	defaultForegroundColor *RGB
+	ansiSequenceRegexMap   map[string]string
+	foregroundColor        *RGB
+	backgroundColor        *RGB
 	defaultBackgroundColor *RGB
-
-	shadowBaseColor string
-	shadowRadius    uint8
-	shadowOffsetX   float64
-	shadowOffsetY   float64
-
-	padding float64
-	margin  float64
-
-	regular     font.Face
-	bold        font.Face
-	italic      font.Face
-	lineSpacing float64
-
-	// canvas switches
-	style                string
-	backgroundColor      *RGB
-	foregroundColor      *RGB
-	ansiSequenceRegexMap map[string]string
+	Path                   string
+	AnsiString             string
+	Author                 string
+	shadowBaseColor        string
+	style                  string
+	BgColor                string
+	shadowOffsetX          float64
+	padding                float64
+	margin                 float64
+	factor                 float64
+	shadowOffsetY          float64
+	rows                   int
+	lineSpacing            float64
+	RPromptOffset          int
+	CursorPadding          int
+	columns                int
+	shadowRadius           uint8
 }
 
 func (ir *Renderer) Init(env runtime.Environment) error {
@@ -154,6 +145,8 @@ func (ir *Renderer) Init(env runtime.Environment) error {
 
 	ir.cleanContent()
 
+	font_.SetCache(env.Cache())
+
 	if err := ir.loadFonts(); err != nil {
 		return &ConnectionError{reason: err.Error()}
 	}
@@ -228,7 +221,7 @@ func (ir *Renderer) setOutputPath(config string) {
 func (ir *Renderer) loadFonts() error {
 	var data []byte
 
-	fontCachePath := filepath.Join(ir.env.CachePath(), "Hack.zip")
+	fontCachePath := filepath.Join(cache.Path(), "Hack.zip")
 	if _, err := stdOS.Stat(fontCachePath); err == nil {
 		data, _ = stdOS.ReadFile(fontCachePath)
 	}
@@ -238,7 +231,7 @@ func (ir *Renderer) loadFonts() error {
 		url := "https://github.com/ryanoasis/nerd-fonts/releases/download/v3.2.1/Hack.zip"
 		var err error
 
-		data, err = fontCLI.Download(url)
+		data, err = font_.Download(url)
 		if err != nil {
 			return err
 		}
